==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/dav/l10n/pt_BR.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendário",
    "Todos" : "Tarefas",
    "Personal" : "Pessoal",
    "{actor} created calendar {calendar}" : "{actor} criou o calendário {calendar}",
    "You created calendar {calendar}" : "Você criou o calendário {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} excluiu o calendário {calendar}",
    "You deleted calendar {calendar}" : "Você excluiu o calendário {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} atualizou o calendário {calendar}",
    "You updated calendar {calendar}" : "Você atualizou o calendário {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartilhou o calendário  {calendar} com você",
    "You shared calendar {calendar} with {user}" : "Você compartilhou o calendário {calendar} com {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartilhou o calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} descompartilhou o calendário {calendar} com você",
    "You unshared calendar {calendar} from {user}" : "Você descompartilhou o calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} descompartilhou o calendário {calendar} de {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} descompartilhou o calendário {calendar} deles mesmos",
    "You shared calendar {calendar} with group {group}" : "Você compartilhou o calendário {calendar} com o grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartilhou o calendário {calendar} com o grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Você descompartilhou o calendário {calendar} do grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} descompartilhou o calendário {calendar} do grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} criou o evento {event} no calendário {calendar}",
    "You created event {event} in calendar {calendar}" : "Você criou o evento {event} no calendário {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} excluiu o evento {event} do calendário {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Você excluiu o evento {event} do calendário {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} atualizou o evento {event} no calendário {calendar}",
    "You updated event {event} in calendar {calendar}" : "Você atualizou o evento {event} no calendário {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} criou a tarefa {todo} na lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Você criou a tarefa {todo} na lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} excluiu a tarefa {todo} da lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Você excluiu a tarefa {todo} da lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} atualizou a tarefa {todo} na lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Você atualizou a tarefa {todo} na lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} tarefa resolvida {todo} na lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Você terminou a tarefa  {todo} na lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabriu tarefa {todo} na lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Você reabriu a terefa {todo} na lista {calendar}",
    "A <strong>calendar</strong> was modified" : "Um <strong>calendário</strong> foi modificado",
    "A calendar <strong>event</strong> was modified" : "Um <strong>evento</strong> do calendário foi modificado",
    "A calendar <strong>todo</strong> was modified" : "Uma <strong>tarefa</strong> do calendário foi modificada",
    "Contact birthdays" : "Aniversário dos contatos",
    "%s via %s" : "%s via %s",
    "Invitation canceled" : "Convite cancelado",
    "Hello %s," : "Olá %s,",
    "The meeting »%s« with %s was canceled." : "A reunião »%s« com %s foi cancelada.",
    "Invitation updated" : "Convite atualizado",
    "The meeting »%s« with %s was updated." : "A reunião »%s« com %s foi atualizada..",
    "%s invited you to »%s«" : "%s convidou você para »%s«",
    "When:" : "Quando:",
    "Where:" : "Onde:",
    "Description:" : "Descrição:",
    "Link:" : "Link:",
    "Contacts" : "Contatos",
    "Technical details" : "Detalhes técnicos",
    "Remote Address: %s" : "Endereço remoto: %s",
    "Request ID: %s" : "ID do solicitante: %s",
    "CalDAV server" : "Servidor CalDAV",
    "Send invitations to attendees" : "Envie convites aos participantes",
    "Please make sure to properly set up the email settings above." : "Certifique-se de configurar corretamente o email acima."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/dav/l10n/pt_BR.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendário",
    "Todos" : "Tarefas",
    "Personal" : "Pessoal",
    "{actor} created calendar {calendar}" : "{actor} criou o calendário {calendar}",
    "You created calendar {calendar}" : "Você criou o calendário {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} excluiu o calendário {calendar}",
    "You deleted calendar {calendar}" : "Você excluiu o calendário {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} atualizou o calendário {calendar}",
    "You updated calendar {calendar}" : "Você atualizou o calendário {calendar}",
    "You shared calendar {calendar} as public link" : "Você compartilhou o calendário {calendar} como um link público",
    "You removed public link for calendar {calendar}" : "Você removeu o link público para o calendário {calendar} ",
    "{actor} shared calendar {calendar} with you" : "{actor} compartilhou o calendário  {calendar} com você",
    "You shared calendar {calendar} with {user}" : "Você compartilhou o calendário {calendar} com {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartilhou o calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} descompartilhou o calendário {calendar} com você",
    "You unshared calendar {calendar} from {user}" : "Você descompartilhou o calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} descompartilhou o calendário {calendar} de {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} descompartilhou o calendário {calendar} deles mesmos",
    "You shared calendar {calendar} with group {group}" : "Você compartilhou o calendário {calendar} com o grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartilhou o calendário {calendar} com o grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Você descompartilhou o calendário {calendar} do grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} descompartilhou o calendário {calendar} do grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} criou o evento {event} no calendário {calendar}",
    "You created event {event} in calendar {calendar}" : "Você criou o evento {event} no calendário {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} excluiu o evento {event} do calendário {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Você excluiu o evento {event} do calendário {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} atualizou o evento {event} no calendário {calendar}",
    "You updated event {event} in calendar {calendar}" : "Você atualizou o evento {event} no calendário {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} criou a tarefa {todo} na lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Você criou a tarefa {todo} na lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} excluiu a tarefa {todo} da lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Você excluiu a tarefa {todo} da lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} atualizou a tarefa {todo} na lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Você atualizou a tarefa {todo} na lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} tarefa resolvida {todo} na lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Você terminou a tarefa  {todo} na lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabriu tarefa {todo} na lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Você reabriu a terefa {todo} na lista {calendar}",
    "A <strong>calendar</strong> was modified" : "Um <strong>calendário</strong> foi modificado",
    "A calendar <strong>event</strong> was modified" : "Um <strong>evento</strong> do calendário foi modificado",
    "A calendar <strong>todo</strong> was modified" : "Uma <strong>tarefa</strong> do calendário foi modificada",
    "Contact birthdays" : "Aniversário dos contatos",
    "%s via %s" : "%s via %s",
    "Invitation canceled" : "Convite cancelado",
    "Hello %s," : "Olá %s,",
    "The meeting »%s« with %s was canceled." : "A reunião »%s« com %s foi cancelada.",
    "Invitation updated" : "Convite atualizado",
    "The meeting »%s« with %s was updated." : "A reunião »%s« com %s foi atualizada..",
    "%s invited you to »%s«" : "%s convidou você para »%s«",
    "When:" : "Quando:",
    "Where:" : "Onde:",
    "Description:" : "Descrição:",
    "Link:" : "Link:",
    "Contacts" : "Contatos",
    "Technical details" : "Detalhes técnicos",
    "Remote Address: %s" : "Endereço remoto: %s",
    "Request ID: %s" : "ID do solicitante: %s",
    "CalDAV server" : "Servidor CalDAV",
    "Send invitations to attendees" : "Envie convites aos participantes",
    "Please make sure to properly set up the email settings above." : "Certifique-se de configurar corretamente o email acima.",
    "Automatically generate a birthday calendar" : "Gerar um calendário de aniversários automaticamente",
    "Birthday calendars will be generated by a background job." : "Os calendários de aniversários serão gerados na retaguarda.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Portanto, eles não estarão disponíveis imediatamente ao habilitar, mas após algum tempo."
},
"nplurals=2; plural=(n > 1);");
